==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetAuditorsInteractions.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAuditorsInteractions] (
	@Instance Varchar(50) = NULL, @SearchCriteria Varchar(50) = NULL, @SearchExpression Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

 	SELECT t.ID								'id',
			u.lastname + ' ' + u.Firstname		'name',
			u.Firstname							'firstname',
			u.lastname							'lastname',
			u.email								'email',
			U.[IsLocalSupervisor]				'isLocalSupervisor',
			U.[IsExternalSupervisor]			'isExternalSupervisor',
			U.[IsExternalAgent]					'isExternalAgent',
			t.CreatedDate						'createdDate',
			t.CreatedByUserId					'createdByUserId',
			t.LastModifiedDate					'lastModifiedDate',
			t.LastModifiedByUserId				'lastModifiedByUserId',
			count(1) - sum(CASE WHEN a.Completed=0 THEN 0 ELSE 1 END) 'uncompleteInteractions',
			ISNULL(sum(a.InteractionDuration),0)	'interactionTimeSum'
		FROM Auditor t
		FULL JOIN [user] u ON (t.Instance = u.VCC AND t.id = u.ID)
		FULL OUTER JOIN AuditorEvaluationPlan a ON ( t.Instance = a.Instance AND t.ID = a.IdAuditor)
		WHERE t.Instance = @Instance
			AND ISNULL(t.ID, '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END

			-- SE AGREGA LA VERIFICACION DE QUE EL USER NO SEA NULL PORQUE AL NO EXISTIR EL USUARIO EN LA TABLA USER MUESTRA FILAS CON NULL. SE PRUEBA EN LOS ENDPOINTS: SAVE_USER, DELETE_USER Y EN GET_AUDITORS_INTERACTIONS.
			AND u.[Firstname] IS NOT NULL
			AND u.[LastName] IS NOT NULL
		GROUP BY
			t.ID,
			u.lastname + ' ' + u.Firstname,
			u.Firstname,
			u.lastname,
			u.email,
			U.[IsLocalSupervisor],
			U.[IsExternalSupervisor],
			U.[IsExternalAgent],
			t.CreatedDate,
			t.CreatedByUserId,
			t.LastModifiedDate,
			t.LastModifiedByUserId

 	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetAuditorsInteractions.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAuditorsInteractions] (
	@Instance Varchar(50) = NULL, @SearchCriteria Varchar(50) = NULL, @SearchExpression Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

 	SELECT t.ID								'id',
			u.lastname + ' ' + u.Firstname		'name',
			u.Firstname							'firstname',
			u.lastname							'lastname',
			u.email								'email',
			U.[IsLocalSupervisor]				'isLocalSupervisor',
			U.[IsExternalSupervisor]			'isExternalSupervisor',
			U.[IsExternalAgent]					'isExternalAgent',
			t.CreatedDate						'createdDate',
			t.CreatedByUserId					'createdByUserId',
			t.LastModifiedDate					'lastModifiedDate',
			t.LastModifiedByUserId				'lastModifiedByUserId',
			count(1) - sum(CASE WHEN a.Completed=0 THEN 0 ELSE 1 END) 'uncompleteInteractions',
			ISNULL(sum(a.InteractionDuration),0)	'interactionTimeSum'
		FROM [dbo].[Auditor] t (NOLOCK)
		INNER JOIN [dbo].[user] u (NOLOCK)
			ON t.Instance = u.VCC 
				AND t.id = u.ID
		FULL OUTER JOIN [dbo].[AuditorEvaluationPlan] a (NOLOCK)
			ON ( 
				t.Instance = a.Instance 
				AND 
				t.ID = a.IdAuditor
			)
		WHERE t.Instance = @Instance
			AND ISNULL(t.ID, '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END

			-- SE AGREGA LA VERIFICACION DE QUE EL USER NO SEA NULL PORQUE AL NO EXISTIR EL USUARIO EN LA TABLA USER MUESTRA FILAS CON NULL. SE PRUEBA EN LOS ENDPOINTS: SAVE_USER, DELETE_USER Y EN GET_AUDITORS_INTERACTIONS.
			AND u.[Firstname] IS NOT NULL
			AND u.[LastName] IS NOT NULL
		GROUP BY
			t.ID,
			u.lastname + ' ' + u.Firstname,
			u.Firstname,
			u.lastname,
			u.email,
			U.[IsLocalSupervisor],
			U.[IsExternalSupervisor],
			U.[IsExternalAgent],
			t.CreatedDate,
			t.CreatedByUserId,
			t.LastModifiedDate,
			t.LastModifiedByUserId

 	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
